# `xchainpy2_thorchain-query

Thorchain-query module to query thorchain for estimation of swaps/ add and remove Liquidity and checking a transaction stage. 
Returns a TxDetail object with all the information needed to conduct a swap, or add liquidity. This includes estimateAddSavers()
